@@ -138,18 +138,21 @@ def description(descfile):
 
 
 @condition
-def family_metadata(family_directory):
+def metadata_file(family_directory):
+    if family_directory:
+        pb_file = os.path.join(family_directory, "METADATA.pb")
+        if os.path.exists(pb_file):
+            return pb_file
+
+@condition
+def family_metadata(metadata_file):
     from google.protobuf import text_format
     from fontbakery.utils import get_FamilyProto_Message
-
-    if family_directory:
-        try:
-            pb_file = os.path.join(family_directory, "METADATA.pb")
-            if os.path.exists(pb_file):
-                return get_FamilyProto_Message(pb_file)
-        except text_format.ParseError:
-            return None
-
+    if metadata_file:
+      try:
+          return get_FamilyProto_Message(metadata_file)
+      except text_format.ParseError:
+          return None
 
 @condition
 def registered_vendor_ids():
@@ -547,3 +550,37 @@ def production_metadata():
     meta_url = "http://fonts.google.com/metadata/fonts"
     # can't do requests.get("url").json() since request text starts with ")]}'"
     return json.loads(requests.get(meta_url).text[5:])
+
+
+@condition
+def GFAxisRegistry():
+    from fontbakery.axes_pb2 import AxisProto
+    from fontbakery.utils import get_Protobuf_Message
+    from pkg_resources import resource_filename
+
+    def normalize_name(name):
+        return ''.join(name.split(' '))
+
+    registry = {}
+    def append_AxisMessage(path):
+        axis_dict = {"message": get_Protobuf_Message(AxisProto, path),
+                     "fallbacks": {}}
+        for fb in axis_dict["message"].fallback:
+            axis_dict["fallbacks"][normalize_name(fb.name)] = fb.value
+        registry[axis_dict["message"].tag] = axis_dict
+
+    for axis in ["casual.textproto",
+                 "cursive.textproto",
+                 "flair.textproto",
+                 "grade.textproto",
+                 "italic.textproto",
+                 "monospace.textproto",
+                 "optical_size.textproto",
+                 "slant.textproto",
+                 "softness.textproto",
+                 "volume.textproto",
+                 "weight.textproto",
+                 "width.textproto",
+                 "wonky.textproto"]:
+        append_AxisMessage(resource_filename('fontbakery', 'data/' + axis))
+    return registry
