@@ -5,8 +5,10 @@ from fontbakery.callable import condition, check, disable
 from fontbakery.message import Message
 from fontbakery.fonts_profile import profile_factory
 from fontbakery.profiles.opentype import OPENTYPE_PROFILE_CHECKS
+from fontbakery.profiles.outline import OUTLINE_PROFILE_CHECKS
 
 profile_imports = ('fontbakery.profiles.opentype',
+                   'fontbakery.profiles.outline',
                    '.shared_conditions')
 profile = profile_factory(default_section=Section("Universal"))
 
@@ -23,6 +25,7 @@ SUPERFAMILY_CHECKS = [
 
 UNIVERSAL_PROFILE_CHECKS = \
     OPENTYPE_PROFILE_CHECKS + \
+    OUTLINE_PROFILE_CHECKS + \
     THIRDPARTY_CHECKS + \
     SUPERFAMILY_CHECKS + [
         'com.google.fonts/check/name/trailing_spaces',
@@ -71,7 +74,7 @@ def com_google_fonts_check_name_trailing_spaces(ttFont):
 
 @check(
     id = 'com.google.fonts/check/family/win_ascent_and_descent',
-    conditions = ['vmetrics'],
+    conditions = ['vmetrics', 'not is_cjk_font'],
     rationale = """
         A font's winAscent and winDescent values should be greater than the head table's yMax, abs(yMin) values. If they are less than these values, clipping can occur on Windows platforms (https://github.com/RedHatBrand/Overpass/issues/33).
 
@@ -130,6 +133,7 @@ def com_google_fonts_check_family_win_ascent_and_descent(ttFont, vmetrics):
 
 @check(
     id = 'com.google.fonts/check/os2_metrics_match_hhea',
+    conditions = ['not is_cjk_font'],
     rationale = """
         When OS/2 and hhea vertical metrics match, the same linespacing results on macOS, GNU+Linux and Windows. Unfortunately as of 2018, Google Fonts has released many fonts with vertical metrics that don't match in this way. When we fix this issue in these existing families, we will create a visible change in line/paragraph layout for either Windows or macOS users, which will upset some of them.
 
@@ -355,26 +359,39 @@ def com_google_fonts_check_fontbakery_version():
 @check(
     id = 'com.google.fonts/check/mandatory_glyphs',
     rationale = """
-        The OpenType specification v1.8.2 recommends that the first glyph is the .notdef glyph without a codepoint assigned and with a drawing.
+        The OpenType specification v1.8.2 recommends that the first glyph is the '.notdef' glyph without a codepoint assigned and with a drawing.
 
         https://docs.microsoft.com/en-us/typography/opentype/spec/recom#glyph-0-the-notdef-glyph
 
-        Pre-v1.8, it was recommended that a font should also contain a .null, CR and space glyph. This might have been relevant for applications on MacOS 9.
+        Pre-v1.8, it was recommended that fonts should also contain 'space', 'CR' and '.null' glyphs. This might have been relevant for MacOS 9 applications.
     """
 )
 def com_google_fonts_check_mandatory_glyphs(ttFont):
-    """Font contains .notdef as first glyph?"""
+    """Font contains '.notdef' as its first glyph?"""
     from fontbakery.utils import glyph_has_ink
 
-    if (ttFont.getGlyphOrder()[0] == ".notdef"
-        and ".notdef" not in ttFont.getBestCmap().values()
-        and glyph_has_ink(ttFont, ".notdef")):
-        yield PASS, ("Font contains the .notdef glyph as the first glyph, it does "
-                     "not have a Unicode value assigned and contains a drawing.")
-    else:
-        yield WARN, ("Font should contain the .notdef glyph as the first glyph, "
-                     "it should not have a Unicode value assigned and should "
-                     "contain a drawing.")
+    passed = True
+    if ttFont.getGlyphOrder()[0] != ".notdef":
+        passed = False
+        yield WARN,\
+              Message('first-glyph',
+                      "Font should contain the .notdef glyph as the first glyph.")
+
+    if ".notdef" in ttFont.getBestCmap().values():
+        passed = False
+        yield WARN,\
+              Message('codepoint',
+                      f"Glyph '.notdef' should not have a Unicode codepoint value assigned,"
+                      f" but got 0x{ttFont.getBestCmap().values()['.notdef']:04X}.")
+
+    if not glyph_has_ink(ttFont, ".notdef"):
+        passed = False
+        yield WARN,\
+              Message('empty',
+                      "Glyph '.notdef' should contain a drawing, but it is empty.")
+
+    if passed:
+        yield PASS, "OK"
 
 
 @check(
@@ -538,15 +555,15 @@ def com_google_fonts_check_required_tables(ttFont):
     """Font contains all required tables?"""
     from .shared_conditions import is_variable_font
 
-    REQUIRED_TABLES = {"cmap", "head", "hhea", "hmtx",
-                       "maxp", "name", "OS/2", "post"}
+    REQUIRED_TABLES = ["cmap", "head", "hhea", "hmtx",
+                       "maxp", "name", "OS/2", "post"]
 
-    OPTIONAL_TABLES = {"cvt ", "fpgm", "loca", "prep",
+    OPTIONAL_TABLES = ["cvt ", "fpgm", "loca", "prep",
                        "VORG", "EBDT", "EBLC", "EBSC",
                        "BASE", "GPOS", "GSUB", "JSTF",
                        "DSIG", "gasp", "hdmx", "LTSH",
                        "PCLT", "VDMX", "vhea", "vmtx",
-                       "kern"}
+                       "kern"]
     # See https://github.com/googlefonts/fontbakery/issues/617
     #
     # We should collect the rationale behind the need for each of the
@@ -565,7 +582,7 @@ def com_google_fonts_check_required_tables(ttFont):
     if is_variable_font(ttFont):
         # According to https://github.com/googlefonts/fontbakery/issues/1671
         # STAT table is required on WebKit on MacOS 10.12 for variable fonts.
-        REQUIRED_TABLES.add("STAT")
+        REQUIRED_TABLES.append("STAT")
 
     missing_tables = [req for req in REQUIRED_TABLES
                       if req not in ttFont.keys()]
@@ -665,7 +682,7 @@ def com_google_fonts_check_STAT_strings(ttFont):
               Message("bad-italic",
                       f'The following AxisValue entries on the STAT table'
                       f' should not contain "Italic":\n'
-                      f' {list(bad_values)}')
+                      f' {list(sorted(bad_values))}')
 
     if passed:
         yield PASS, "Looks good!"
