@@ -68,11 +68,6 @@ def unindent_rationale(rationale, checkid=None):
             content += "\n"
             continue
 
-        if checkid and line[:8].strip() != "":
-            import sys
-            sys.exit(f"FATAL ERROR: The rationale metadata"
-                     f" on '{checkid}' must be indented by 8 spaces!")
-
         # all lines are assumed to be indented by 8 spaces
         content += line[8:] + "\n"
     return content
@@ -240,15 +235,23 @@ def get_font_glyph_data(font):
             })
     return font_data
 
-
-def get_FamilyProto_Message(path):
-    from fontbakery.fonts_public_pb2 import FamilyProto
+def get_Protobuf_Message(klass, path):
     from google.protobuf import text_format
-    message = FamilyProto()
+    message = klass()
     text_data = open(path, "rb").read()
     text_format.Merge(text_data, message)
     return message
 
+def get_FamilyProto_Message(path):
+    from fontbakery.fonts_public_pb2 import FamilyProto
+    return get_Protobuf_Message(FamilyProto, path)
+
+def get_DesignerInfoProto_Message(text_data):
+    from fontbakery.designers_pb2 import DesignerInfoProto
+    from google.protobuf import text_format
+    message = DesignerInfoProto()
+    text_format.Merge(text_data, message)
+    return message
 
 def check_bit_entry(ttFont, table, attr, expected, bitmask, bitname):
     from fontbakery.message import Message
