@@ -323,7 +323,7 @@ def test_check_ots():
     bogus_font = TEST_FILE("README.txt")
     message = assert_results_contain(check(bogus_font),
                                      FAIL, None) # FIXME: This needs a message keyword
-    assert "invalid version tag" in message
+    assert "invalid sfntVersion" in message
     assert "Failed to sanitize file!" in message
 
 
@@ -339,8 +339,18 @@ def test_check_mandatory_glyphs():
     subsetter = fontTools.subset.Subsetter()
     subsetter.populate(glyphs="n")  # Arbitrarily remove everything except n.
     subsetter.subset(ttFont)
+    # It seems that fontTools automatically adds '.notdef' as the 1st glyph
+    # but as an empty one, so the check should complain about it:
     assert_results_contain(check(ttFont),
-                           WARN, None) # FIXME: This needs a message keyword
+                           WARN, 'empty')
+    # FIXME: The assumption above should be double-checked!
+
+
+    # TODO: assert_results_contain(check(ttFont),
+    #                              WARN, 'codepoint')
+
+    # TODO: assert_results_contain(check(ttFont),
+    #                              WARN, 'first-glyph')
 
 
 def test_check_whitespace_glyphs():
